##  How to Activate
**Caution**
  * Activating the extension is irreversible. Once activated, you cannot roll back to the previous naming behavior. Reverting requires contacting support. For more, see [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support?locale=en-US&state=PRODUCTION&version=CLOUD "If you encounter issues, have questions, or need assistance with SAP LeanIX, our support team is here to help. You can contact support directly within SAP LeanIX or submit a request in the SAP for Me portal.").
  * This extension fully overwrites any existing display name adjustments for IT components. If you have previously requested changes to how IT component names are composed, for example, through a support ticket, those adjustments will be replaced.


  1. Go tothe Administration area in your workspace.
  2. Navigate to the Optional Features and Early Access section.
  3. SelectUpdate your IT Component naming rule.
  4. Give your consent to extend the meta model and selectActivate Extension.
